// Single-player level objects...these are simply SimObjects
// with fields set on them.

// Description of mission vars
// Mission tick = 5 seconds
// $Game::StartBots       - start with this many bots...
// $Game::MinBotTicks     - spawn new bot no sooner than this
// $Game::MaxBotTicks     - spawn new bot no later than this
// $Game::SPBots          - current number of living bots
// $Game::DeadBots        - number of bots killed so far
// $Game::MaxSpawnBots    - spawn no more than this many bots
// $Game::MaxLiveBots     - spawn no more than this many bots at one time
// $Game::EndBots         - end mission when this many bots killed (unless 0)
// $Game::MaxMissionTicks - end mission after this many ticks (unless 0)
// $Game::BronzePoints    - how many points for bronze bot?
// $Game::SilverPoints    - how many points for silver bot?
// $Game::GoldPoints      - how many points for gold bot?
// $Game::BossPoints      - how many points for boss bot?
// $Game::BrainPoints     - how many points for brain?
// $Game::QuickShotTime   - how long (in ms) for quick shot bonus?
// $Game::LevelType       - Battle, Boss, or Brain
// $Game::MissionSeq      - what level object ot use for parameters
// $Game::MissionSeqTotal - level number regardless of looping missions

if (isObject(SPLevels)) SPLevels.delete();
new SimGroup(SPLevels);
$Game::MissionSeq = 0;
$Game::MissionSeqTotal = 0;

//--------------------------------------------------------
// Green levels -- first time
//--------------------------------------------------------

%level = new SimObject(SPLevel1)
{
   // these are the basic global difficulty settings (affect
   // difficulty of bronze, silver, gold on this level).
   damageScale = 0.4;
   armorScale  = 0.2;
   fireScale   = 0.5;

   startBots = 4;
   maxLiveBots = 5;
   maxSpawnBots = 6;
   endBots = 6;
   minBotTicks = 1;
   maxBotTicks = 3;
   maxMissionTicks = 0;

   quickShotTime = 2500;

   // all bronze -- assume these numbers add to 100...if they don't they'll be off
   bronze = 100;
   silver = 0;
   gold = 0;

   // mostly medium -- assume these numbers add to 100...if they don't they'll be off
   light = 20;
   medium = 60;
   heavy = 20;

   bronzePts = 50;
   silverPts = 100;
   goldPts = 150;
   bossPts = 3000;
   brainPts = 100;

   levelType = "Battle";
   mission = "TT1_1";
   missionBriefing = "News of your escape has reached Alien Mind Control.  They have set their bots on search and destroy. You must think fast and move quickly to defeat them.";
   };

SPLevels.add(%level);

%level = new SimObject(SPLevel2 : SPLevel1)
{
   startBots = 4;
   maxSpawnBots = 7;
   endBots = 7;

   light = 30;
   medium = 40;
   heavy = 30;

   mission = "TT1_2";
   missionBriefing = "You have succeeded defeating ground force one.  Alien Mind Control has called in the heavy artillery.  Keep on your toes, they are gunning for you.";
   };
SPLevels.add(%level);

%level = new SimObject(SPLevel3 : SPLevel2)
{
   startBots = 6;
   maxSpawnBots = 10;
   endBots = 10;
   minBotTicks = 1;
   maxBotTicks = 2;

   light = 40;
   medium = 20;
   heavy = 40;

   mission = "TT1_3";
   missionBriefing = "Your superb battle tactics have enabled you to overcome the heavy artillery, but there is much more to do.  Alien Mind Control has been working on advancing their bots and you will encounter tougher resistance.  New challenges await you as you face off against the feared Special Forces Unit.";
};
SPLevels.add(%level);

%level = new SimObject(SPLevel4 : SPLevel3)
{
   startBots = 6;
   maxSpawnBots = 9;
   endBots = 9;

   bronze = 20;
   silver = 30;
   gold = 50;

   light = 30;
   medium = 40;
   heavy = 30;

   levelType = "Boss";
   mission = "TT1_4";
   missionBriefing = "Congratulations, you have defeated the Alien Mind Control Special Forces unit, but the planet is not yet free. Defeat the Boss-bot Assimov, then free his enslaved brain prisoners and escape this world.  Good Luck!";
};
SPLevels.add(%level);

%level = new SimObject(SPLevel5 : SPLevel4)
{
   startBots = 0;
   maxSpawnBots = 0;
   endBots = 1; // i.e., never since we don't spawn any
   maxMissionTicks = 12; // one minute...

   levelType = "Brain";
   mission = "GreenBrain";
   missionBriefing = "You have beaten their last line of defense. But they are regrouping. Quickly gather the enslaved brains and get off the planet while you still have time.";
};
SPLevels.add(%level);

// Add to scales and bonuses here, then go to level 1 mimic below
// after which we continue on to level 2...
%level = new SimObject(SPLevel6)
{
   gotolevel = "7";

   // these are all increases...
   addDamageScale = 0.1;
   addArmorScale  = 0.1;
   addFireScale   = 0.1;
   addBronzePts = 0;
   addSilverPts = 0;
   addGoldPts = 0;
   addBossPts = 3000;
   addBrainPts = 0;
};
SPLevels.add(%level);

//--------------------------------------------------------
// Blue levels -- first time
//--------------------------------------------------------
%level = new SimObject(SPLevel7 : SPLevel1)
{
   startBots = 7;
   maxSpawnBots = 15;
   endBots = 15;

   bronze = 50;
   silver = 50;
   gold = 0;

   light = 20;
   medium = 60;
   heavy = 20;

   mission = "TT2_1";
   missionBriefing = "News of your successful defeat of Assimov has reached Alien Mind Control.  They have constructed more bots, so you will face some heavy resistance on this planet.  These new bots are smarter, faster and have more firepower. Watch you back!";
};
SPLevels.add(%level);

%level = new SimObject(SPLevel8 : SPLevel7)
{
   startBots = 7;
   maxSpawnBots = 15;
   endBots = 15;

   light = 30;
   medium = 40;
   heavy = 30;

   mission = "TT2_2";
   missionBriefing = "Alien Mind Control was impressed with your fighting tactics. Level two bots have been rewired to put up even more resistance. Be prepared for some heavy engagement.";
};
SPLevels.add(%level);

%level = new SimObject(SPLevel9 : SPLevel8)
{
   startBots = 8;
   maxSpawnBots = 16;
   endBots = 16;
   minBotTicks = 1;
   maxBotTicks = 2;

   light = 40;
   medium = 20;
   heavy = 40;

   mission = "TT2_3";
   missionBriefing = "Good Work. The Rewired bots have fallen and the planet is almost yours.  Rumor has it that Alien Mind Control is developing a superior model bot and they are sending all they have in to stop you.  You must defeat them.";
};

SPLevels.add(%level);

%level = new SimObject(SPLevel10 : SPLevel9)
{
   bronze = 20;
   silver = 30;
   gold = 50;

   light = 30;
   medium = 40;
   heavy = 30;

   levelType = "Boss";
   mission = "TT2_4";
   missionBriefing = "Victory is within your grasp. Boss-bot Zeus will make sure you come up empty handed. Overwhelm him and save more prisoners. They are depending on you!";
};

SPLevels.add(%level);

%level = new SimObject(SPLevel11 : SPLevel10)
{
   startBots = 0;
   maxSpawnBots = 0;
   endBots = 1; // i.e., never since we don't spawn any
   maxMissionTicks = 12; // one minute...

   levelType = "Brain";
   mission = "BlueBrain";
   missionBriefing = "You have beaten their last line of defense. But they are regrouping. Quickly gather the enslaved brains and get off the planet while you still have time.";
};
SPLevels.add(%level);

// Add to scales and bonuses here, then go to level 1 mimic below
// after which we continue on to level 2...
%level = new SimObject(SPLevel12)
{
   gotolevel = "13";

   // these are all increases...
   addDamageScale = 0.1;
   addArmorScale  = 0.1;
   addFireScale   = 0.1;
   addBronzePts = 0;
   addSilverPts = 0;
   addGoldPts = 0;
   addBossPts = 3000;
   addBrainPts = 0;
};
SPLevels.add(%level);

//--------------------------------------------------------
// Red levels -- first time
//--------------------------------------------------------
%level = new SimObject(SPLevel13 : SPLevel7)
{
   bronze = 30;
   silver = 40;
   gold = 30;

   mission = "TT3_1";
   missionBriefing = "Congratulations on the defeat of Zeus.  Your skill and desire to be free has led you to the battlegrounds of a scorched volcanic world. You will need to use all your battle tactics to conquer this heavily guarded last outpost of Alien Mind Control.  They have developed Annihilator Bots and deployed them on this planet to destroy you.  Good Luck!";
};
SPLevels.add(%level);

%level = new SimObject(SPLevel14 : SPLevel13)
{
   startBots = 10;
   maxSpawnBots = 20;
   endBots = 20;

   // unlike previous rounds...shift to harder bots across red levels
   bronze = 30;
   silver = 30;
   gold = 40;

   light = 30;
   medium = 40;
   heavy = 30;

   mission = "TT3_2";
   missionBriefing = "You are fortunate to have survived the wrath of the Annihilators.  It won't be so easy next time, as they are adept at learning your tactics and using them against you.  The higher you advance, the harder it will be to destroy them.";
};
SPLevels.add(%level);

%level = new SimObject(SPLevel15 : SPLevel14)
{
   startBots = 12;
   maxSpawnBots = 25;
   endBots = 25;
   minBotTicks = 1;
   maxBotTicks = 2;

   // unlike previous rounds...shift to harder bots across red levels
   bronze = 20;
   silver = 30;
   gold = 50;

   minBotTicks = 1;
   maxBotTicks = 2;

   light = 40;
   medium = 20;
   heavy = 40;

   mission = "TT3_3";
   missionBriefing = "You are becoming quite a celebrity back at Alien Mind Control.  They have continued to construct more Annihilators to match your wits.  Keep alive, and keep your mind clear!";
};
SPLevels.add(%level);

%level = new SimObject(SPLevel16 : SPLevel15)
{
   bronze = 20;
   silver = 30;
   gold = 50;

   light = 30;
   medium = 40;
   heavy = 30;

   levelType = "Boss";
   mission = "TT3_4";
   missionBriefing = "In a last-ditch attempt at thwarting your escape, Alien Mind Control has deployed feared Boss-bot Hugo, and emptied their entire reserves against you.  You must use all your battle saavy and strength to defeat this last wave of attackers.  The prisoners are counting on your success.";
};
SPLevels.add(%level);

%level = new SimObject(SPLevel17 : SPLevel16)
{
   startBots = 0;
   maxSpawnBots = 0;
   endBots = 1; // i.e., never since we don't spawn any
   maxMissionTicks = 14; // one minute, ten seconds...

   levelType = "Brain";
   mission = "RedBrain";
   missionBriefing = "You have beaten their last line of defense. But they are regrouping. Quickly gather the enslaved brains and get off the planet while you still have time.";
};
SPLevels.add(%level);

// Add to scales and bonuses here, then go to level 1 mimic below
// after which we continue on to level 2...
%level = new SimObject(SPLevel18)
{
   gotolevel = "19";

   // these are all increases...
   addDamageScale = 0.1;
   addArmorScale  = 0.1;
   addFireScale   = 0.1;
   addBronzePts = 50;
   addSilverPts = 100;
   addGoldPts = 150;
   addBossPts = 3000;
   addBrainPts = 100;
};
SPLevels.add(%level);

%level = new SimObject(SPLevel19 : SPLevel1)
{
   missionBriefing = "You have successfully conquered all three planets, but your job is not yet done.  You must go back and rescue new prisoners of Alien Mind Control. This time around, they will not be so gentle. Be careful and good luck.";
};
SPLevels.add(%level);

%level = new SimObject(SPLevel20)
{
   gotolevel = "2";
};
SPLevels.add(%level);
